# SPDX-License-Identifier: Apache-2.0
# Copyright (C) 2026, The Exgentic organization and its contributors.

## CLI usage:
# exgentic evaluate --benchmark swebench --agent tool_calling --num-tasks 30 \
#   --model gpt-4o
## Python API usage:
# from exgentic import RunConfig, evaluate
# evaluate(RunConfig(benchmark="swebench", agent="tool_calling", num_tasks=30,
#   model="gpt-4o"))
## Direct class usage (this script):
# SWEBenchBenchmark + LiteLLMToolCallingAgent

from exgentic import LiteLLMToolCallingAgent, SWEBenchBenchmark, evaluate


def main() -> None:
    benchmark = SWEBenchBenchmark()
    agent = LiteLLMToolCallingAgent(model="gpt-4o")
    evaluate(benchmark=benchmark, agent=agent, output_dir="./outputs", num_tasks=30)


if __name__ == "__main__":
    main()



# SPDX-License-Identifier: Apache-2.0
# Copyright (C) 2026, The Exgentic organization and its contributors.

import os
from pathlib import Path

if "TAU2_DATA_DIR" not in os.environ:
    os.environ["TAU2_DATA_DIR"] = str(Path(__file__).resolve().parent / "installation" / "tau2-bench" / "data")
